use napi::bindgen_prelude::*;
use napi_derive::napi;
use shedron::interpret::Interpreter;
use shedron::parser::Lexer;

#[napi]
pub fn run(env: Env, input: String) -> Result<Vec<i128>> {
    let mut lexer = Lexer::new(&input);

    let ast = match lexer.parse() {
        Ok(tree) => tree,
        Err(e) => {
            env.throw_syntax_error(&format!("{e}"), None)?;
            return Ok(Vec::new())
        },
    };

    let output = match Interpreter::new().run(ast) {
        Ok(out) => out,
        Err(e) => {
            env.throw_error(&format!("{e}"), None)?;
            return Ok(Vec::new())
        },
    };

    Ok(output.rolls)
}
